panorama
========

Create panorama in one run. Uses hugin for the real work.

Installation
------------

```
pip install panorama
```

Usage
-----

```
create-panorama-from-jpg-files-in-directory file_containing_jpg_files
```
